Uses of Class
org.matomo.java.tracking.CustomVariable
-
Packages that use CustomVariable Package Description org.matomo.java.tracking org.piwik.java.tracking -
-
Uses of CustomVariable in org.matomo.java.tracking
Methods in org.matomo.java.tracking that return CustomVariable Modifier and Type Method Description CustomVariableMatomoRequest. getPageCustomVariable(int index)Get the page custom variable at the specified index.CustomVariableMatomoRequest. getVisitCustomVariable(int index)Get the visit custom variable at the specified index.Methods in org.matomo.java.tracking with parameters of type CustomVariable Modifier and Type Method Description voidMatomoRequest. setPageCustomVariable(CustomVariable customVariable, int index)Set a page custom variable at the specified index.voidMatomoRequest. setVisitCustomVariable(CustomVariable customVariable, int index)Set a user custom variable at the specified key.Method parameters in org.matomo.java.tracking with type arguments of type CustomVariable Modifier and Type Method Description MatomoRequestBuilderMatomoRequestBuilder. pageCustomVariables(List<CustomVariable> pageCustomVariables)MatomoRequestBuilderMatomoRequestBuilder. visitCustomVariables(List<CustomVariable> visitCustomVariables) -
Uses of CustomVariable in org.piwik.java.tracking
Subclasses of CustomVariable in org.piwik.java.tracking Modifier and Type Class Description classCustomVariableDeprecated.UseCustomVariableinstead.
-