Package org.matomo.java.tracking
package org.matomo.java.tracking
-
ClassDescriptionA user defined custom variable.Represents an item in an ecommerce order.Object representing a locale required by some Matomo query parameters.A datetime object that will return the datetime in the format
yyyy-MM-dd hh:mm:ss.Object representing a locale required by some Matomo query parameters.A class that implements the Matomo Tracking HTTP API.A class that sendsMatomoRequests to a specified Matomo server.