Uses of Package
org.matomo.java.tracking
Packages that use org.matomo.java.tracking
-
Classes in org.matomo.java.tracking used by org.matomo.java.trackingClassDescriptionA user defined custom variable.Represents an item in an ecommerce order.A datetime object that will return the datetime in the format
yyyy-MM-dd hh:mm:ss.Object representing a locale required by some Matomo query parameters.A class that implements the Matomo Tracking HTTP API. -
Classes in org.matomo.java.tracking used by org.piwik.java.trackingClassDescriptionA user defined custom variable.Represents an item in an ecommerce order.A datetime object that will return the datetime in the format
yyyy-MM-dd hh:mm:ss.Object representing a locale required by some Matomo query parameters.A class that implements the Matomo Tracking HTTP API.A class that sendsMatomoRequests to a specified Matomo server.