All Classes and Interfaces
Class
Description
A user defined custom variable.
Deprecated.
Represents an item in an ecommerce order.
Deprecated.
Use
EcommerceItem instead.Object representing a locale required by some Matomo query parameters.
A datetime object that will return the datetime in the format
yyyy-MM-dd hh:mm:ss.Object representing a locale required by some Matomo query parameters.
A class that implements the
Matomo Tracking HTTP API.
A class that sends
MatomoRequests to a specified Matomo server.Deprecated.
Use
MatomoDate instead.Deprecated.
Use
MatomoLocale instead.Deprecated.
Use
MatomoRequest instead.Deprecated.
Use
MatomoTracker instead.
CustomVariableinstead.