All Classes
-
All Classes Class Summary Exception Summary Class Description CustomVariable A user defined custom variable.CustomVariable Deprecated. UseCustomVariableinstead.EcommerceItem Represents an item in an ecommerce order.EcommerceItem Deprecated. UseEcommerceIteminstead.InvalidUrlException MatomoBoolean Object representing a locale required by some Matomo query parameters.MatomoDate A datetime object that will return the datetime in the formatyyyy-MM-dd hh:mm:ss.MatomoException MatomoLocale Object representing a locale required by some Matomo query parameters.MatomoRequest A class that implements the Matomo Tracking HTTP API.MatomoRequestBuilder MatomoTracker A class that sendsMatomoRequests to a specified Matomo server.PiwikDate Deprecated. UseMatomoDateinstead.PiwikLocale Deprecated. UseMatomoLocaleinstead.PiwikRequest Deprecated. UseMatomoRequestinstead.PiwikTracker Deprecated. UseMatomoTrackerinstead.QueryParameters