Package org.matomo.java.tracking
-
Class Summary Class Description CustomVariable A user defined custom variable.EcommerceItem Represents an item in an ecommerce order.MatomoBoolean Object representing a locale required by some Matomo query parameters.MatomoDate A datetime object that will return the datetime in the formatyyyy-MM-dd hh:mm:ss.MatomoLocale Object representing a locale required by some Matomo query parameters.MatomoRequest A class that implements the Matomo Tracking HTTP API.MatomoRequestBuilder MatomoTracker A class that sendsMatomoRequests to a specified Matomo server.QueryParameters -
Exception Summary Exception Description InvalidUrlException MatomoException