Uses of Package
org.matomo.java.tracking
-
Packages that use org.matomo.java.tracking Package Description org.matomo.java.tracking org.piwik.java.tracking -
Classes in org.matomo.java.tracking used by org.matomo.java.tracking Class Description CustomVariable A user defined custom variable.EcommerceItem Represents an item in an ecommerce order.MatomoDate A datetime object that will return the datetime in the formatyyyy-MM-dd hh:mm:ss.MatomoLocale Object representing a locale required by some Matomo query parameters.MatomoRequest A class that implements the Matomo Tracking HTTP API.MatomoRequestBuilder -
Classes in org.matomo.java.tracking used by org.piwik.java.tracking Class Description CustomVariable A user defined custom variable.EcommerceItem Represents an item in an ecommerce order.MatomoDate A datetime object that will return the datetime in the formatyyyy-MM-dd hh:mm:ss.MatomoLocale Object representing a locale required by some Matomo query parameters.MatomoRequest A class that implements the Matomo Tracking HTTP API.MatomoTracker A class that sendsMatomoRequests to a specified Matomo server.